@@ -16,6 +16,7 @@
 #include <QFileInfo>
 #include <QVBoxLayout>
 #include <QFontDatabase>
+#include <QDebug>
 
 DWIDGET_USE_NAMESPACE
 
@@ -68,6 +69,7 @@ DFInstallNormalWindow::DFInstallNormalWindow(const QStringList &files, QWidget *
     , m_pworker(new Worker())
     , m_pthread(new QThread())
 {
+    qDebug() << "DFInstallNormalWindow created with" << files.size() << "font files to install";
     initUI();
     initConnections();
     m_pworker->moveToThread(m_pthread);
@@ -84,7 +86,7 @@ DFInstallNormalWindow::DFInstallNormalWindow(const QStringList &files, QWidget *
 *************************************************************************/
 DFInstallNormalWindow::~DFInstallNormalWindow()
 {
-    qDebug() << __func__ << "start" << endl;
+    qDebug() << "DFInstallNormalWindow destructor start";
 
     // 结束线程
     m_pthread->quit();
@@ -111,7 +113,7 @@ DFInstallNormalWindow::~DFInstallNormalWindow()
         //恢复标志位
         m_skipStateRecovery = false;
     }
-    qDebug() << __func__ << "end" << this << endl;
+    qDebug() << "DFInstallNormalWindow destructor end";
 }
 
 /*************************************************************************
@@ -220,7 +222,7 @@ void DFInstallNormalWindow::getAllSysfiles()
             QString systemFileName;
             systemFileName.append(font.fontInfo.familyName).append(font.fontInfo.styleName);
             m_fontName.append(font.fontData.strFontName);
-            qDebug() << font.fontInfo.fullname << endl;
+            qDebug() << font.fontInfo.fullname << Qt::endl;
             m_AllSysFilesfamilyName.append(systemFileName);
 
         }
@@ -259,7 +261,7 @@ void DFInstallNormalWindow::verifyFontFiles()
         }
         if (Q_UNLIKELY(fontInfo.isError)) {
             m_damagedFiles.append(it);
-
+            qWarning() << "Found damaged font file:" << QFileInfo(it).fileName();
 #ifdef QT_QML_DEBUG
 //            qDebug() << __FUNCTION__ << " (" << it << " :Damaged file)";
 #endif
@@ -275,7 +277,7 @@ void DFInstallNormalWindow::verifyFontFiles()
 #endif
         } else if (isSystemFont(fontInfo)) {
             m_systemFiles.append(it);
-
+            qInfo() << "Found system font:" << QFileInfo(it).fileName();
 #ifdef QT_QML_DEBUG
 //            qDebug() << __FUNCTION__ << " (" << it << " :System file)";
 #endif
@@ -389,17 +391,17 @@ bool DFInstallNormalWindow::isSystemFont(DFontInfo &f)
 *************************************************************************/
 void DFInstallNormalWindow::checkShowMessage()
 {
-    qDebug() << "Install over" << endl;
+    qDebug() << "Font installation process completed";
 
     if (getInstallMessage == true && getReInstallMessage == true) {
         qDebug() << "install refresh over";
         finishInstall();
     } else if (getInstallMessage == true && m_popedInstallErrorDialg == false) {
         if (ifNeedShowExceptionWindow()) {
-            qDebug() << "need reinstall " << endl;
+            qDebug() << "need reinstall " << Qt::endl;
             Q_EMIT sigShowInstallErrDlg();
         } else {
-            qDebug() << "no need reinstall" << endl;
+            qDebug() << "no need reinstall" << Qt::endl;
             //不需恢复添加按钮tab状态
             m_skipStateRecovery = true;
             finishInstall();
@@ -530,7 +532,7 @@ void DFInstallNormalWindow::batchInstall()
 //        qDebug() << " Prepare install file: " << it + "|" + familyName;
     }
 
-//    qDebug() << installListWithFamliyName << endl;
+//    qDebug() << installListWithFamliyName << Qt::endl;
 
     if (ifNeedShowExceptionWindow()) {
         m_fontManager->setCacheStatus(FontManagerCore::CacheLater);
@@ -555,7 +557,7 @@ void DFInstallNormalWindow::batchInstall()
 *************************************************************************/
 void DFInstallNormalWindow::batchReInstall(const QStringList &reinstallFiles)
 {
-    qDebug() << "start" << __FUNCTION__ << endl;
+    qDebug() << "start" << __FUNCTION__ << Qt::endl;
 
     QStringList installListWithFamliyName;
     for (auto &it : reinstallFiles) {
@@ -585,7 +587,7 @@ void DFInstallNormalWindow::batchHalfwayInstall(const QStringList &filelist)
     m_installFiles = filelist;
     verifyFontFiles();
 
-    qDebug() << m_newHalfInstalledFiles.count() << "*" << m_oldHalfInstalledFiles.count() << endl;
+    qDebug() << m_newHalfInstalledFiles.count() << "*" << m_oldHalfInstalledFiles.count() << Qt::endl;
     m_halfInstalledFiles.append(m_newHalfInstalledFiles);
 
     //当安装的字体是需要新添加到字体验证框时或者已经添加到字体验证框时,刷新listview.
@@ -799,7 +801,7 @@ void DFInstallNormalWindow::showInstallErrDlg()
         finishInstall();
     });
 
-    qDebug() << geometry().center() << "+" << m_pexceptionDlg->rect().center() << endl;
+    qDebug() << geometry().center() << "+" << m_pexceptionDlg->rect().center() << Qt::endl;
 
     m_pexceptionDlg->move(geometry().center() - m_pexceptionDlg->rect().center());
     m_pexceptionDlg->exec();
