@@ -1,31 +1,40 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="sr">
 <context>
     <name>Category</name>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="362"/>
         <source>All Fonts</source>
         <translation>Сви фонтови</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="363"/>
         <source>System</source>
         <translation>Систем</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="364"/>
         <source>User</source>
         <translation>Корисник</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="365"/>
         <source>Favorites</source>
         <translation>Омиљено</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="366"/>
         <source>Active</source>
         <translation>Активно</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="367"/>
         <source>Chinese</source>
         <translation>Кинаски</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="368"/>
         <source>Monospaced</source>
         <translation>Истог размака</translation>
     </message>
@@ -33,6 +42,7 @@
 <context>
     <name>DFDeleteDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="139"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Откажи</translation>
@@ -41,10 +51,12 @@
 <context>
     <name>DFDeleteTTCDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="550"/>
         <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
         <translation>%1 је породица фонтова, ако нставите, сви фонтови у њој ће бити обрисани</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="544"/>
         <source>Delete</source>
         <comment>button</comment>
         <translation>Обриши</translation>
@@ -53,19 +65,23 @@
 <context>
     <name>DFDisableTTCDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="563"/>
         <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
         <translation>%1 је породица фонтова, ако нставите, сви фонтови у њој ће бити омогућени</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="565"/>
         <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
         <translation>%1 је породица фонтова, ако нставите, сви фонтови у њој ће бити онемогућени</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="576"/>
         <source>Enable</source>
         <comment>button</comment>
         <translation>Омогући</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="578"/>
         <source>Disable</source>
         <comment>button</comment>
         <translation>Онемогући</translation>
@@ -74,10 +90,12 @@
 <context>
     <name>DFHandleTTCDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="467"/>
         <source>Apply to all selected font families</source>
         <translation>Примени на све изабране породице фонтова</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="480"/>
         <source>Cancel</source>
         <translation>Откажи</translation>
     </message>
@@ -85,14 +103,17 @@
 <context>
     <name>DFInstallErrorDialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="103"/>
         <source>Broken file</source>
         <translation>Оштећена датотека</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="114"/>
         <source>Same version installed</source>
         <translation>Иста верзија је инсталирана</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="125"/>
         <source>System Font</source>
         <translation>Системски фонт</translation>
     </message>
@@ -100,66 +121,82 @@
 <context>
     <name>DFontMgrMainWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="371"/>
         <source>Ctrl+Shift+/</source>
         <translation>Ctrl+Shift+/</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="384"/>
         <source>PgUp</source>
         <translation>PgUp</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="403"/>
         <source>PgDown</source>
         <translation>PgDown</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="423"/>
         <source>Ctrl+Alt+F</source>
         <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="441"/>
         <source>Ctrl+F</source>
         <translation>Ctrl+F</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="521"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="326"/>
         <source>Ctrl+=</source>
         <translation>Ctrl+=</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="342"/>
         <source>Ctrl+-</source>
         <translation>Ctrl+-</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="358"/>
         <source>Ctrl+0</source>
         <translation>Ctrl+0</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1654"/>
         <source>%1 font installed</source>
         <translation>%1 фонт инсталиран</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1656"/>
         <source>%1 fonts installed</source>
         <translation>%1 фонтова инсталирано</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="474"/>
         <source>Alt+M</source>
         <translation>Alt+M</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="562"/>
         <source>CTRL+I</source>
         <translation>CTRL+I</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1661"/>
         <source>Failed to install %1 font. There is not enough disk space.</source>
-        <translation type="unfinished"/>
+        <translation>Не успело да се инсталира %1 font. Нema довољно простора на диску.</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1663"/>
         <source>Failed to install %1 fonts. There is not enough disk space.</source>
         <translation>Неуспешно инсталирање %1 фонта/ова. Недовољно простора на диску.</translation>
     </message>
     <message>
+        <location filename="../libdeepin-font-manager/dcopyfilesmanager.h" line="12"/>
         <source>Fonts</source>
         <translation>Фонтови</translation>
     </message>
@@ -167,6 +204,7 @@
 <context>
     <name>DFontWidget</name>
     <message>
+        <location filename="../libdeepin-font-manager/dfontwidget.cpp" line="127"/>
         <source>Broken file</source>
         <translation>Оштећена датотека</translation>
     </message>
@@ -174,30 +212,37 @@
 <context>
     <name>DeleteConfirmDailog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="229"/>
         <source>This font will not be available to applications</source>
         <translation>Овај фонт неће бити доступан програмима</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="231"/>
         <source>These fonts will not be available to applications</source>
         <translation>Ови фонтови неће бити доступни програмима</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="234"/>
         <source>The other %1 system fonts cannot be deleted</source>
         <translation>Осталих %1 системских фонтова се не могу уклонити</translation>
     </message>
     <message>
-        <source>The font &quot;%1&quot; in use cannot be deleted</source>
-        <translation>Фонт &quot;%1&quot; се користи и не може се уклонити</translation>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="237"/>
+        <source>The font "%1" in use cannot be deleted</source>
+        <translation>Фонт "%1" се користи и не може се уклонити</translation>
     </message>
     <message>
-        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
-        <translation>Осталих %1 системких фонтова и фонт &quot;%2&quot; који се користи се не могу уклонити</translation>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="240"/>
+        <source>The other %1 system fonts and the font "%2" in use cannot be deleted</source>
+        <translation>Осталих %1 системких фонтова и фонт "%2" који се користи се не могу уклонити</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="204"/>
         <source>Are you sure you want to delete %1 font(s)?</source>
         <translation>Заиста желите да обришете %1 фонт/а/ова?</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="140"/>
         <source>Delete</source>
         <comment>button</comment>
         <translation>Обриши</translation>
@@ -206,6 +251,7 @@
 <context>
     <name>Dfuninstalldialog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="74"/>
         <source>Deleting fonts, please wait...</source>
         <translation>Уклањање фонтова, сачекајте...</translation>
     </message>
@@ -213,18 +259,22 @@
 <context>
     <name>ExceptionWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="151"/>
         <source>Font Verification</source>
         <translation>Провера фонта</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="252"/>
         <source>No fonts to be installed</source>
         <translation>Нема фонтова за инсталацију</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="186"/>
         <source>Exit</source>
         <translation>Изађи</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="187"/>
         <source>Continue</source>
         <translation>Настави</translation>
     </message>
@@ -232,84 +282,103 @@
 <context>
     <name>Font</name>
     <message>
-        <source>Don&apos;t let your dreams be dreams</source>
+        <location filename="../libdeepin-font-manager/dfontpreviewitemdef.h" line="15"/>
+        <source>Don't let your dreams be dreams</source>
         <translation>Не дозволи да твоји снови остану снови</translation>
     </message>
 </context>
 <context>
     <name>FontDetailDailog</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="131"/>
         <source>Basic info</source>
         <translation>Основни подаци</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="60"/>
         <source>Style</source>
         <translation>Стил</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="62"/>
         <source>Type</source>
         <translation>Врста</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="66"/>
         <source>Version</source>
         <translation>Верзија</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="72"/>
         <source>Description</source>
         <translation>Опис</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="73"/>
         <source>Unknown</source>
         <translation>Непознато</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="78"/>
         <source>Full name</source>
         <translation>Пуно име</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="79"/>
         <source>Ps name</source>
         <translation>П.С. име</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="80"/>
         <source>Trademark</source>
         <translation>Заштитни знак</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="123"/>
         <source>Copyright</source>
-        <translation type="unfinished"/>
+        <translation>Ауторски права</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="124"/>
         <source>License Description</source>
-        <translation type="unfinished"/>
+        <translation>Опис лиценце</translation>
     </message>
 </context>
 <context>
     <name>Main</name>
     <message>
+        <location filename="../deepin-font-manager/main.cpp" line="60"/>
         <source>Font Manager</source>
         <translation>Управник Фонтова</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/main.cpp" line="61"/>
         <source>Font Manager helps users install and manage fonts.</source>
         <translation>Управник Фонтова помаже корисницима да инсталирају и управљају са фонтовима.</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="37"/>
         <source>Loading fonts, please wait...</source>
         <translation>Учитавање фонтова, сачекајте...</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2093"/>
         <source>The font exported to your desktop</source>
         <translation>Фонт је извезен на радну површину</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2095"/>
         <source>%1 fonts exported to your desktop</source>
         <translation>%1 фонта/ова је извезено на радну површину</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2099"/>
         <source>Failed to export 1 font. There is not enough disk space.</source>
         <translation>Неуспешан извоз 1 фонта. Недовољно простора на диску.</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2102"/>
         <source>Failed to export %1 fonts. There is not enough disk space.</source>
         <translation>Неуспешан извоз %1 фонта/ова. Недовољно простора на диску.</translation>
     </message>
@@ -317,38 +386,47 @@
 <context>
     <name>Menu</name>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="63"/>
         <source>Add font</source>
         <translation>Додај фонт</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="71"/>
         <source>Enable</source>
         <translation>Омогући</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="297"/>
         <source>Disable</source>
         <translation>Онемогући</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="73"/>
         <source>Delete</source>
         <translation>Обриши</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="77"/>
         <source>Favorite</source>
         <translation>Омиљено</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="278"/>
         <source>Unfavorite</source>
         <translation>Уклони из омиљеног</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="80"/>
         <source>Details</source>
         <translation>Детаљи</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="83"/>
         <source>Display in file manager</source>
         <translation>Прикажи у управнику података</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="75"/>
         <source>Export</source>
         <translation>Извези</translation>
     </message>
@@ -356,22 +434,27 @@
 <context>
     <name>MessageManager</name>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1875"/>
         <source>deactivated</source>
         <translation>деактивирано</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1877"/>
         <source>The fonts have been deactivated</source>
         <translation>Фонт је деактивиран</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1867"/>
         <source>%1 is in use, so you cannot disable it</source>
         <translation>%1 се користи и не можете га онемогућити</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1869"/>
         <source>You cannot disable system fonts and the fonts in use</source>
         <translation>Не можете онемогућити системке фонтове и фонтеве који се користе</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1871"/>
         <source>You cannot disable system fonts</source>
         <translation>Не можете онемогућити системске фонтове</translation>
     </message>
@@ -379,10 +462,12 @@
 <context>
     <name>NormalInstallWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="130"/>
         <source>Install Font</source>
         <translation>Инсталирај фонт</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="143"/>
         <source>Verifying...</source>
         <translation>Проверавање...</translation>
     </message>
@@ -390,22 +475,27 @@
 <context>
     <name>QuickInstallWindow</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="77"/>
         <source>Unknown</source>
         <translation>Непознато</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="206"/>
         <source>Broken file</source>
         <translation>Оштећена датотека</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="227"/>
         <source>Installed</source>
         <translation>Инсталиран</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="232"/>
         <source>Not Installed</source>
         <translation>Није инсталиран</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="127"/>
         <source>Install Font</source>
         <translation>Инсталирај фонт</translation>
     </message>
@@ -413,14 +503,17 @@
 <context>
     <name>SearchBar</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="653"/>
         <source>Search</source>
         <translation>Претражи</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="838"/>
         <source>No search results</source>
         <translation>Нема резутата претраге</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="860"/>
         <source>No fonts</source>
         <translation>Нема фонта</translation>
     </message>
@@ -428,38 +521,47 @@
 <context>
     <name>Shortcut</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2275"/>
         <source>Help</source>
         <translation>Помоћ</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2280"/>
         <source>Display shortcuts</source>
         <translation>Прикажи пречице</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2281"/>
         <source>Page up</source>
         <translation>Страница нагоре</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2282"/>
         <source>Page down</source>
         <translation> Страница надоле</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2285"/>
         <source>Delete</source>
         <translation>Обриши</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2286"/>
         <source>Add font</source>
         <translation>Додај фонт</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2287"/>
         <source>Favorite</source>
         <translation>Омиљено</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2288"/>
         <source>Unfavorite</source>
         <translation>Уклони из омиљеног</translation>
     </message>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2289"/>
         <source>Font info</source>
         <translation>Подаци фонта</translation>
     </message>
@@ -467,8 +569,9 @@
 <context>
     <name>StateBar</name>
     <message>
+        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="901"/>
         <source>Input preview text</source>
         <translation>Унеси текст за преглед</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
